/*
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *  
 *  Copyright (C) 2008 Liam Girdwood  
 */
 
#include <stdio.h>
#include <unistd.h>
#include "ascenario.h"

int main(int argc, char *argv[])
{
	struct snd_scenario *scn;
	int num, i, err;
	const char **list;
	
	/* init library */
	scn = snd_scenario_init("default");
	if (scn == NULL) {
		printf("%s: failed to init\n", argv[0]);
		return 0;
	}

	/* get list of scenarios */
	num = snd_scenario_list(scn, &list);
	if (num == 0)
		printf("%s: no scenarios\n", argv[0]);
	else
		printf("got %d scenarios\n", num);
	
	/* set each scenario */
	for (i = 0; i < num; i++) {
		printf("changing to %s\n", list[i]);
		
		err = snd_scenario_set_scn(scn, list[i]);
		if (err < 0) {
			printf("failed to set scenario: %s\n", list[i]);
			continue;
		}
		
		printf("  master playback volume ID = %d\n", 
			snd_scenario_get_master_playback_volume(scn));
		printf("  master playback switch ID = %d\n", 
			snd_scenario_get_master_playback_switch(scn));
		printf("  master capture volume ID = %d\n", 
			snd_scenario_get_master_capture_volume(scn));
		printf("  master capture switch ID = %d\n", 
			snd_scenario_get_master_capture_switch(scn));
		sleep(2);
	}
	
	snd_scenario_exit(scn);
	return 0;
}
